SystemOrganization addCategory: #'System-Applications'!

Object subclass: #AppRegistry
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

AppRegistry class
	instanceVariableNames: 'registeredClasses default'!

!AppRegistry commentStamp: 'ads 4/2/2003 15:30' prior: 0!
AppRegistry is a simple little class, not much more than a wrapper around a collection. It's intended to help break dependencies between packages. For example, if you'd like to be able to send e-mail, you could use the bare-bones MailComposition class, or you could use the full-blown Celeste e-mail client. Instead of choosing one or the other, you can call "MailSender default" (where MailSender is a subclass of AppRegistry), and thus avoid creating a hard-coded dependency on either of the two mail senders.

This will only really be useful, of course, for applications that have a very simple, general, well-defined interface. Most of the time, you're probably better off just marking your package as being dependent on a specific other package, and avoiding the hassle of this whole AppRegistry thing. But for simple things like e-mail senders or web browsers, it might be useful.
!

AppRegistry class
	instanceVariableNames: 'registeredClasses default'!

!AppRegistry class methodsFor: 'registering' stamp: 'ads 3/29/2003 13:36'!
appName
	"Defaults to the class name, which is probably good enough, but you could override this in subclasses if you want to."
	^ self name! !

!AppRegistry class methodsFor: 'singleton' stamp: 'StephaneDucasse 1/28/2011 15:16'!
askForDefault
        "self askForDefault"
        self registeredClasses isEmpty ifTrue:
                [self inform: 'There are no ', self appName, ' applications registered.'.
                ^ default := nil].
        self registeredClasses size = 1 ifTrue:
                [^ default := self registeredClasses anyOne].
        ^Smalltalk globals
                at: #UIManager
                ifPresent: [:class | self chooseAppWithUI]
                ifAbsent:  [| stream |
                        stream := WriteStream with: 'You have to choose a Class by using ''#chooseApp: index:'''.
                        stream nextPut: Character cr.
                        self registeredClasses doWithIndex: [:class :index |
                                stream
                                        nextPutAll: index asString;
                                        nextPutAll: ' - ';
                                        nextPutAll: class name asString;
                                        nextPut: Character cr].
                        self inform: stream contents.
                        default := nil]! !

!AppRegistry class methodsFor: 'private' stamp: 'SeanDeNigris 9/15/2010 01:24'!
askForNewDefaultOnNextRequest

	default := nil.! !

!AppRegistry class methodsFor: 'private' stamp: 'StephaneDucasse 1/28/2011 15:16'!
chooseApp: anIndex

        ^default := self registeredClasses at: anIndex ifAbsent: [nil]! !

!AppRegistry class methodsFor: 'cleanup' stamp: 'StephaneDucasse 3/9/2010 16:16'!
cleanUp
	"AppRegistry cleanUp"

	self removeObsolete.! !

!AppRegistry class methodsFor: 'singleton' stamp: 'ads 3/29/2003 13:11'!
default
	^ default ifNil: [self askForDefault]! !

!AppRegistry class methodsFor: 'singleton' stamp: 'BenjaminVanRyseghem 2/24/2012 15:51'!
default: aClassOrNil
	"Sets my default to aClassOrNil. 
	Answers the old default."
	| oldDefault |
	oldDefault := default.
	aClassOrNil ifNotNil: [ self register: aClassOrNil ].
	default := aClassOrNil.
	^ oldDefault! !

!AppRegistry class methodsFor: 'singleton' stamp: 'nk 3/9/2004 12:35'!
defaultOrNil
	^ default! !

!AppRegistry class methodsFor: 'registering' stamp: 'SeanDeNigris 9/15/2010 01:25'!
register: aProviderClass

	(self registeredClasses includes: aProviderClass) ifTrue: [ ^ self ].
	
	self askForNewDefaultOnNextRequest.	"if you're registering a new app you probably want to use it"
	self registeredClasses add: aProviderClass.! !

!AppRegistry class methodsFor: 'registering' stamp: 'ads 3/29/2003 13:01'!
registeredClasses
	^ registeredClasses ifNil: [registeredClasses := OrderedCollection new]! !

!AppRegistry class methodsFor: 'cleanup' stamp: 'StephaneDucasse 1/30/2011 21:35'!
removeObsolete
	"AppRegistry removeObsolete"
	self registeredClasses copy do:[:cls| 
		(cls class isObsolete or:[cls isBehavior and:[cls isObsolete]]) 
			ifTrue:[self unregister: cls]].
	self subclasses do:[:cls| cls removeObsolete].! !

!AppRegistry class methodsFor: 'cleanup' stamp: 'StephaneDucasse 1/30/2011 21:38'!
reset
	"AppRegistry reset"

	registeredClasses := nil.! !

!AppRegistry class methodsFor: 'registering' stamp: 'ads 3/29/2003 13:03'!
unregister: aProviderClass
	(default = aProviderClass) ifTrue: [default := nil].
	self registeredClasses remove: aProviderClass ifAbsent: [].! !

!AppRegistry methodsFor: 'notes' stamp: 'ads 4/2/2003 15:04'!
seeClassSide
	"All the code for AppRegistry is on the class side."! !

AppRegistry subclass: #MailSender
	instanceVariableNames: ''
	classVariableNames: 'SmtpServer UserName'
	poolDictionaries: ''
	category: 'System-Applications'!

!MailSender class methodsFor: 'testing' stamp: 'dvf 5/11/2002 01:31'!
isSmtpServerSet
	^ SmtpServer notNil and: [SmtpServer notEmpty]
! !

!MailSender class methodsFor: 'communication' stamp: 'ads 5/11/2003 21:11'!
sendMessage: aMailMessage

	self default ifNotNil: [self default sendMailMessage: aMailMessage]! !

!MailSender class methodsFor: 'settings' stamp: 'rbb 3/1/2005 10:59'!
setSmtpServer
	"Set the SMTP server used to send outgoing messages via"
	SmtpServer ifNil: [SmtpServer := ''].
	SmtpServer := UIManager default
		request: 'What is your mail server for outgoing mail?'
		initialAnswer: SmtpServer.
! !

!MailSender class methodsFor: 'settings' stamp: 'md 9/29/2010 17:54'!
setSmtpServer: aString
	SmtpServer := aString! !

!MailSender class methodsFor: 'settings' stamp: 'rbb 3/1/2005 11:00'!
setUserName
	"Change the user's email name for use in composing messages."

	(UserName isNil) ifTrue: [UserName := ''].
	UserName := UIManager default
		request: 'What is your email address?\(This is the address other people will reply to you)' withCRs
		initialAnswer: UserName.
	UserName ifNotNil: [UserName := UserName]! !

!MailSender class methodsFor: 'accessing' stamp: 'dvf 5/11/2002 01:29'!
smtpServer
	"Answer the server for sending email"

	self isSmtpServerSet
		ifFalse: [self setSmtpServer].
	SmtpServer isEmpty ifTrue: [
		self error: 'no SMTP server specified' ].

	^SmtpServer! !

!MailSender class methodsFor: 'accessing' stamp: 'dvf 5/11/2002 00:49'!
userName
	"Answer the user name to be used in composing messages."

	(UserName isNil or: [UserName isEmpty])
		ifTrue: [self setUserName].

	UserName isEmpty ifTrue: [ self error: 'no user name specified' ].

	^UserName! !

AppRegistry subclass: #PrettyPrinting
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

!PrettyPrinting class methodsFor: 'class initialization' stamp: 'damiencassou 7/30/2009 10:55'!
initialize
	"I'm a registry as well as a default provider"
	self register: self! !

!PrettyPrinting class methodsFor: 'pretty printing' stamp: 'damiencassou 7/30/2009 10:59'!
prettyPrinterClassFor: aBehavior
	|defaultPrinter|
	defaultPrinter := self default.
	^ (defaultPrinter isNil or: [defaultPrinter = self])
		ifTrue: [aBehavior compilerClass]
		ifFalse: [self default prettyPrinterClassFor: aBehavior]! !

AppRegistry subclass: #SoundService
	instanceVariableNames: ''
	classVariableNames: 'DefaultSoundEnabled'
	poolDictionaries: ''
	category: 'System-Applications'!

!SoundService commentStamp: 'AlainPlantec 1/7/2010 22:41' prior: 0!
This is the AppRegistry class for the sound system.

A sound system offers a small protocol for playing sounds and making beeps and works like a facade towards the rest of Squeak. A sound system is registered in this registry and can be accessed by "SoundService default". This way we decouple the sound system from the rest of Squeak and make it pluggable. It also is a perfect spot to check for the SoundSettings class>>soundEnabled.!

!SoundService class methodsFor: 'settings' stamp: 'StephaneDucasse 1/30/2011 19:09'!
defaultSoundEnabled
	^DefaultSoundEnabled ifNil: [false]! !

!SoundService class methodsFor: 'settings' stamp: 'GuillermoPolito 3/30/2012 11:38'!
soundEnabled
	^ self defaultSoundEnabled! !

!SoundService class methodsFor: 'settings' stamp: 'StephaneDucasse 1/30/2011 19:10'!
soundEnabled: aBoolean
	DefaultSoundEnabled := aBoolean! !

!SoundService class methodsFor: 'settings' stamp: 'HenrikSperreJohansen 1/21/2011 14:22'!
toggleSoundEnabling
     self soundEnabled: self soundEnabled not! !
PrettyPrinting initialize!
